Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/pdf/xpdf/Link.h
diff options
context:
space:
mode:
Diffstat (limited to 'pdf/xpdf/Link.h')
-rw-r--r--pdf/xpdf/Link.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/pdf/xpdf/Link.h b/pdf/xpdf/Link.h
index 62a4c85..71ad0c5 100644
--- a/pdf/xpdf/Link.h
+++ b/pdf/xpdf/Link.h
@@ -200,8 +200,8 @@ private:
class LinkURI: public LinkAction {
public:
- // Build a LinkURI given the URI (string).
- LinkURI(Object *uriObj);
+ // Build a LinkURI given the URI (string) and base URI.
+ LinkURI(Object *uriObj, GString *baseURI);
// Destructor.
virtual ~LinkURI();
@@ -251,7 +251,7 @@ class Link {
public:
// Construct a link, given its dictionary.
- Link(Dict *dict);
+ Link(Dict *dict, GString *baseURI);
// Destructor.
~Link();
@@ -288,7 +288,7 @@ class Links {
public:
// Extract links from array of annotations.
- Links(Object *annots);
+ Links(Object *annots, GString *baseURI);
// Destructor.
~Links();